@@ -73,7 +73,7 @@ class Exceptions:
 
 class DataExchangeClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/dataexchange.html#DataExchange.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/dataexchange.html#DataExchange.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html)
     """
 
@@ -82,13 +82,17 @@ class DataExchangeClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/dataexchange.html#DataExchange.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/dataexchange.html#DataExchange.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#can_paginate)
         """
 
     def cancel_job(self, *, JobId: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/dataexchange.html#DataExchange.Client.cancel_job)
+        This operation cancels a job.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/dataexchange.html#DataExchange.Client.cancel_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#cancel_job)
         """
 
@@ -101,15 +105,19 @@ class DataExchangeClient:
         Tags: Dict[str, str] = None
     ) -> CreateDataSetResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/dataexchange.html#DataExchange.Client.create_data_set)
+        This operation creates a data set.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/dataexchange.html#DataExchange.Client.create_data_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#create_data_set)
         """
 
     def create_job(
-        self, *, Details: RequestDetailsTypeDef, Type: TypeType
+        self, *, Details: "RequestDetailsTypeDef", Type: TypeType
     ) -> CreateJobResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/dataexchange.html#DataExchange.Client.create_job)
+        This operation creates a job.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/dataexchange.html#DataExchange.Client.create_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#create_job)
         """
 
@@ -117,25 +125,33 @@ class DataExchangeClient:
         self, *, DataSetId: str, Comment: str = None, Tags: Dict[str, str] = None
     ) -> CreateRevisionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/dataexchange.html#DataExchange.Client.create_revision)
+        This operation creates a revision for a data set.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/dataexchange.html#DataExchange.Client.create_revision)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#create_revision)
         """
 
     def delete_asset(self, *, AssetId: str, DataSetId: str, RevisionId: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/dataexchange.html#DataExchange.Client.delete_asset)
+        This operation deletes an asset.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/dataexchange.html#DataExchange.Client.delete_asset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#delete_asset)
         """
 
     def delete_data_set(self, *, DataSetId: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/dataexchange.html#DataExchange.Client.delete_data_set)
+        This operation deletes a data set.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/dataexchange.html#DataExchange.Client.delete_data_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#delete_data_set)
         """
 
     def delete_revision(self, *, DataSetId: str, RevisionId: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/dataexchange.html#DataExchange.Client.delete_revision)
+        This operation deletes a revision.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/dataexchange.html#DataExchange.Client.delete_revision)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#delete_revision)
         """
 
@@ -147,7 +163,9 @@ class DataExchangeClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/dataexchange.html#DataExchange.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/dataexchange.html#DataExchange.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#generate_presigned_url)
         """
 
@@ -155,25 +173,33 @@ class DataExchangeClient:
         self, *, AssetId: str, DataSetId: str, RevisionId: str
     ) -> GetAssetResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/dataexchange.html#DataExchange.Client.get_asset)
+        This operation returns information about an asset.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/dataexchange.html#DataExchange.Client.get_asset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#get_asset)
         """
 
     def get_data_set(self, *, DataSetId: str) -> GetDataSetResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/dataexchange.html#DataExchange.Client.get_data_set)
+        This operation returns information about a data set.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/dataexchange.html#DataExchange.Client.get_data_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#get_data_set)
         """
 
     def get_job(self, *, JobId: str) -> GetJobResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/dataexchange.html#DataExchange.Client.get_job)
+        This operation returns information about a job.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/dataexchange.html#DataExchange.Client.get_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#get_job)
         """
 
     def get_revision(self, *, DataSetId: str, RevisionId: str) -> GetRevisionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/dataexchange.html#DataExchange.Client.get_revision)
+        This operation returns information about a revision.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/dataexchange.html#DataExchange.Client.get_revision)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#get_revision)
         """
 
@@ -181,7 +207,10 @@ class DataExchangeClient:
         self, *, DataSetId: str, MaxResults: int = None, NextToken: str = None
     ) -> ListDataSetRevisionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/dataexchange.html#DataExchange.Client.list_data_set_revisions)
+        This operation lists a data set's revisions sorted by CreatedAt in descending
+        order.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/dataexchange.html#DataExchange.Client.list_data_set_revisions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#list_data_set_revisions)
         """
 
@@ -189,7 +218,9 @@ class DataExchangeClient:
         self, *, MaxResults: int = None, NextToken: str = None, Origin: str = None
     ) -> ListDataSetsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/dataexchange.html#DataExchange.Client.list_data_sets)
+        This operation lists your data sets.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/dataexchange.html#DataExchange.Client.list_data_sets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#list_data_sets)
         """
 
@@ -202,7 +233,9 @@ class DataExchangeClient:
         RevisionId: str = None
     ) -> ListJobsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/dataexchange.html#DataExchange.Client.list_jobs)
+        This operation lists your jobs sorted by CreatedAt in descending order.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/dataexchange.html#DataExchange.Client.list_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#list_jobs)
         """
 
@@ -210,31 +243,42 @@ class DataExchangeClient:
         self, *, DataSetId: str, RevisionId: str, MaxResults: int = None, NextToken: str = None
     ) -> ListRevisionAssetsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/dataexchange.html#DataExchange.Client.list_revision_assets)
+        This operation lists a revision's assets sorted alphabetically in descending
+        order.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/dataexchange.html#DataExchange.Client.list_revision_assets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#list_revision_assets)
         """
 
     def list_tags_for_resource(self, *, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/dataexchange.html#DataExchange.Client.list_tags_for_resource)
+        This operation lists the tags on the resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/dataexchange.html#DataExchange.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#list_tags_for_resource)
         """
 
     def start_job(self, *, JobId: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/dataexchange.html#DataExchange.Client.start_job)
+        This operation starts a job.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/dataexchange.html#DataExchange.Client.start_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#start_job)
         """
 
     def tag_resource(self, *, ResourceArn: str, Tags: Dict[str, str]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/dataexchange.html#DataExchange.Client.tag_resource)
+        This operation tags a resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/dataexchange.html#DataExchange.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#tag_resource)
         """
 
     def untag_resource(self, *, ResourceArn: str, TagKeys: List[str]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/dataexchange.html#DataExchange.Client.untag_resource)
+        This operation removes one or more tags from a resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/dataexchange.html#DataExchange.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#untag_resource)
         """
 
@@ -242,7 +286,9 @@ class DataExchangeClient:
         self, *, AssetId: str, DataSetId: str, Name: str, RevisionId: str
     ) -> UpdateAssetResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/dataexchange.html#DataExchange.Client.update_asset)
+        This operation updates an asset.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/dataexchange.html#DataExchange.Client.update_asset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#update_asset)
         """
 
@@ -250,7 +296,9 @@ class DataExchangeClient:
         self, *, DataSetId: str, Description: str = None, Name: str = None
     ) -> UpdateDataSetResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/dataexchange.html#DataExchange.Client.update_data_set)
+        This operation updates a data set.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/dataexchange.html#DataExchange.Client.update_data_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#update_data_set)
         """
 
@@ -258,7 +306,9 @@ class DataExchangeClient:
         self, *, DataSetId: str, RevisionId: str, Comment: str = None, Finalized: bool = None
     ) -> UpdateRevisionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/dataexchange.html#DataExchange.Client.update_revision)
+        This operation updates a revision.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/dataexchange.html#DataExchange.Client.update_revision)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/client.html#update_revision)
         """
 
@@ -267,19 +317,22 @@ class DataExchangeClient:
         self, operation_name: Literal["list_data_set_revisions"]
     ) -> ListDataSetRevisionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/dataexchange.html#DataExchange.Paginator.ListDataSetRevisions)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/paginators.html#listdatasetrevisionspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/dataexchange.html#DataExchange.Paginator.ListDataSetRevisions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/paginators.html#listdatasetrevisionspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_data_sets"]) -> ListDataSetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/dataexchange.html#DataExchange.Paginator.ListDataSets)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/paginators.html#listdatasetspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/dataexchange.html#DataExchange.Paginator.ListDataSets)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/paginators.html#listdatasetspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_jobs"]) -> ListJobsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/dataexchange.html#DataExchange.Paginator.ListJobs)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/paginators.html#listjobspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/dataexchange.html#DataExchange.Paginator.ListJobs)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/paginators.html#listjobspaginator)
         """
 
     @overload
@@ -287,5 +340,6 @@ class DataExchangeClient:
         self, operation_name: Literal["list_revision_assets"]
     ) -> ListRevisionAssetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/dataexchange.html#DataExchange.Paginator.ListRevisionAssets)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/paginators.html#listrevisionassetspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/dataexchange.html#DataExchange.Paginator.ListRevisionAssets)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dataexchange/paginators.html#listrevisionassetspaginator)
         """
